@@ -1,14 +1,7 @@
+import platform
 import toml
-
-try:
-    import Tkinter as tk
-except ImportError:
-    import tkinter as tk
-
-try:
-    import ttk
-except ImportError:
-    import tkinter.ttk as ttk
+import tkinter as tk
+import tkinter.ttk as ttk
 
 import ast
 import sys
@@ -38,6 +31,8 @@ def start_gui():
     '''Starting point when module is the main routine.'''
     global val, w, root, top
 
+    path_check()
+
     Utils.checkversion(__version__)
 
     print('----------------------------\n----- Running fRAT_GUI -----\n----------------------------')
@@ -98,20 +93,33 @@ class GUI:
             self.create_statmap_frame(window)
 
     def change_page_specific_settings(self, window):
+        if platform.system() == 'Darwin':
+            statistics_width = "530"
+            home_width = "512"
+            statmap_width = "500"
+            general_width = "480"
+            parsing_width = "450"
+        else:
+            statistics_width = "550"
+            home_width = "530"
+            statmap_width = "520"
+            general_width = "500"
+            parsing_width = "480"
+
         if self.page == 'Home':
-            window.geometry("512x860")
+            window.geometry(f"{home_width}x860")
         elif self.page == 'General':
-            window.geometry("480x860")
+            window.geometry(f"{general_width}x860")
         elif self.page == 'Analysis':
-            window.geometry("480x860")
+            window.geometry(f"{general_width}x860")
         elif self.page == 'Parsing':
-            window.geometry("450x280")
+            window.geometry(f"{parsing_width}x280")
         elif self.page == 'Plotting':
-            window.geometry("512x860")
+            window.geometry(f"{home_width}x860")
         elif self.page == 'Statistics':
-            window.geometry("530x860")
+            window.geometry(f"{statistics_width}x860")
         elif self.page == 'Statistical_maps':
-            window.geometry("500x860")
+            window.geometry(f"{statmap_width}x860")
 
     def create_statmap_frame(self, window):
         self.statmap_frame = tk.LabelFrame(window)
@@ -839,20 +847,20 @@ def run_tests(GUI):
     GUI.change_frame('General')
     Save_settings(pages, f'roi_analysis/{ConfigurationFiles.analysis_config}')
 
-    path_to_example_data = find_example_dataset()
+    path_to_example_data_input, path_to_example_data_output = find_example_dataset()
 
     # Create tSNR maps and run ROI analysis
-    statmap_calc('Temporal SNR', __version__, 'test_config.toml', path_to_example_data)
-    fRAT('test_config.toml', path_to_example_data)
+    statmap_calc('Temporal SNR', __version__, 'test_config.toml', path_to_example_data_input)
+    fRAT('test_config.toml', path_to_example_data_input)
 
     # Run tests to check if output of fRAT matches the example data
     if General['full_comparison']['Current'] == 'true':
-        roi_output_test = TestDifferences([f'{path_to_example_data}/sub-02/statmaps/test_maps',
-                                            f'{path_to_example_data}/sub-02/statmaps/temporalSNR_report'],
+        roi_output_test = TestDifferences([f'{path_to_example_data_input}/sub-02/statmaps/test_maps',
+                                            f'{path_to_example_data_input}/sub-02/statmaps/temporalSNR_report'],
                                            General['verbose_errors']['Current'])
 
-        voxelwise_map_test = TestDifferences([f'{path_to_example_data}/test_ROI_report',
-                                              f'{path_to_example_data}/HarvardOxford-Cortical_ROI_report'],
+        voxelwise_map_test = TestDifferences([f'{path_to_example_data_input}/test_ROI_report',
+                                              f'{path_to_example_data_output}'],
                                              General['verbose_errors']['Current'])
 
         # Delete files
@@ -860,10 +868,15 @@ def run_tests(GUI):
                 or (General['delete_test_folder']['Current'] == 'If completed without error'
                     and voxelwise_map_test.status == 'No errors'
                     and roi_output_test.status == 'No errors'):
-            shutil.rmtree(f'{path_to_example_data}/test_ROI_report')
-            shutil.rmtree(f'{path_to_example_data}/sub-01/statmaps/test_maps')
-            shutil.rmtree(f'{path_to_example_data}/sub-02/statmaps/test_maps')
-            shutil.rmtree(f'{path_to_example_data}/sub-03/statmaps/test_maps')
+            shutil.rmtree(f'{path_to_example_data_input}/test_ROI_report')
+            shutil.rmtree(f'{path_to_example_data_input}/sub-01/statmaps/test_maps')
+            shutil.rmtree(f'{path_to_example_data_input}/sub-02/statmaps/test_maps')
+            shutil.rmtree(f'{path_to_example_data_input}/sub-03/statmaps/test_maps')
+
+            print('Deleted test folders.')
+
+        else:
+            print('Retaining test folders.')
 
         if voxelwise_map_test.status == 'No errors' and roi_output_test.status == 'No errors':
             print("\n--- End of installation testing, no errors found ---")
@@ -895,19 +908,23 @@ def find_example_dataset():
         raise FileExistsError('More than one subject example dataset folder found in fRAT directory. '
                               'Only keep the version that matches your fRAT version.')
 
-    elif General['full_comparison']['Current'] == 'true' and not output_data_folders:
+    if General['full_comparison']['Current'] == 'true' and not output_data_folders:
         raise FileNotFoundError('Full comparison selected, but HarvardOxford-Cortical_ROI_report is not present in '
                                 '"subject_example_data" folder. Download it from https://osf.io/pbm3d/.')
 
-    return subject_data_folders[0]
+    subject_data_folder = subject_data_folders[0]
+
+    try:
+        output_data_folder = output_data_folders[0]
+    except IndexError:
+        output_data_folder = None
+
+    return subject_data_folder, output_data_folder
 
 
 def check_stale_state():
     current_critical_params = Parsing['parameter_dict1']['Current'].split(', ')
 
-    if current_critical_params == ['']:
-        raise Exception('No critical parameters set in Parsing options.')
-
     dynamic_widgets = itemgetter('table_cols', 'table_rows',
                                  'brain_table_cols', 'brain_table_rows',
                                  'single_roi_fig_colour', 'single_roi_fig_x_axis',
@@ -1116,7 +1133,9 @@ def make_table():
     df.to_csv(f'{base_directory}/paramValues.csv', index=False)
 
     print(f"\nparamValues.csv saved in {base_directory}."
-          f"\n\nMake sure values in paramValues.csv are correct before continuing analysis."
+          f"\n\nMake sure values in paramValues.csv are correct before continuing analysis. Also make sure anatomy "
+          f"scans were not present when setting up parameters, or these lines will need to be removed from "
+          f"paramValues.csv."
           f"\nIf the csv file contains unexpected parameters, update the parsing options in the GUI and rerun setup "
           f"parameters, or manually update them.")
 
@@ -1257,5 +1276,17 @@ def parse_params_from_file_name(json_file_name, cfg=config):
     return keys, param_nums
 
 
+def path_check():
+    try:
+        os.environ['FSLDIR']
+    except KeyError:
+        raise IsADirectoryError("$FSLDIR not in path")
+
+    if os.path.isdir(f"{os.environ['FSLDIR']}/bin"):
+        print(f"\nFSL directory found in {os.environ['FSLDIR']}.")
+    else:
+        raise IsADirectoryError(f"bin folder not found in {os.environ['FSLDIR']}")
+
+
 if __name__ == '__main__':
     start_gui()
